Changelog
---------

0.3.0 (2017-07-10)
~~~~~~~~~~~~~~~~~~~

- Replace csscompress with rcssmin, which produces slightly bigger results but
  does so in a much faster way.
  [href]

0.2.0 (2017-01-11)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to limit the number of used foundation components.
  [href]

0.1.1 (2016-06-20)
~~~~~~~~~~~~~~~~~~~

- Removes the custom pyscss monkey patch, as the issues has been resolved.
  [href]

0.1.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.0.4 (2015-07-13)
~~~~~~~~~~~~~~~~~~~

- Monkey-patches pyscss, to fix its Zurb Foundation compilation.
  See https://github.com/Kronuz/pyScss/pull/342.
  [href]

0.0.3 (2015-06-26)
~~~~~~~~~~~~~~~~~~~

- Adds support for onegov.core.upgrade
  [href]

- Remove support for Python 3.3
  [href]

0.0.2 (2015-05-05)
~~~~~~~~~~~~~~~~~~~

- Upgrade to Zurb Foundation 5.5.2.
  [href]

0.0.1 (2015-04-29)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
